<template>
  <div class="mod-config">
    <basic-container>
      <el-form :inline="true" :model="dataForm" @keyup.enter.native="getDataList()">
        <el-form-item>
          <el-button v-if="permissions.process_finalreport_add" icon="el-icon-plus" type="primary"
                     @click="addOrUpdateHandle()">新增
          </el-button>
        </el-form-item>
      </el-form>

      <div class="avue-crud">
        <el-table
          :data="dataList"
          border
          v-loading="dataListLoading">
          <el-table-column
            fixed
            prop="address"
            header-align="center"
            align="center"
            label="地址">
          </el-table-column>
          <el-table-column
            prop="agentIdea"
            header-align="center"
            align="center"
            label="承 办 人意 见">
          </el-table-column>
          <el-table-column
            prop="agentIdeaSign1"
            header-align="center"
            align="center"
            label="填表人签名">
          </el-table-column>
          <el-table-column
            prop="caseReason"
            header-align="center"
            align="center"
            label="案由">
          </el-table-column>
          <el-table-column
            prop="caseSource"
            header-align="center"
            align="center"
            label="案件来源">
          </el-table-column>
          <el-table-column
            prop="caseStatement"
            header-align="center"
            align="center"
            label="简要案情及查处经过">
          </el-table-column>
          <el-table-column
            prop="citizenName"
            header-align="center"
            align="center"
            label="公民姓名">
          </el-table-column>
          <el-table-column
            prop="crimeAddress"
            header-align="center"
            align="center"
            label="发案地址">
          </el-table-column>
          <el-table-column
            prop="crimeTime"
            header-align="center"
            align="center"
            label="发案时间">
          </el-table-column>
          <el-table-column
            prop="documentNum"
            header-align="center"
            align="center"
            label="行政处罚决定书文号">
          </el-table-column>
          <el-table-column
            prop="executionTime"
            header-align="center"
            align="center"
            label="执行时间">
          </el-table-column>
          <el-table-column
            prop="leaderIdea"
            header-align="center"
            align="center"
            label="领导审批意见">
          </el-table-column>
          <el-table-column
            prop="legalPerson"
            header-align="center"
            align="center"
            label="法定代表人（负责人）姓名">
          </el-table-column>
          <el-table-column
            prop="legislationIdea"
            header-align="center"
            align="center"
            label="法制审核意见">
          </el-table-column>
          <el-table-column
            prop="penaltyDecision"
            header-align="center"
            align="center"
            label="行 政 处 罚 内 容">
          </el-table-column>
          <el-table-column
            prop="penaltyDecisionCase"
            header-align="center"
            align="center"
            label="处罚执行方式及罚没财物的处置情况">
          </el-table-column>
          <el-table-column
            prop="phone"
            header-align="center"
            align="center"
            label="联系电话">
          </el-table-column>
          <el-table-column
            prop="recordTime"
            header-align="center"
            align="center"
            label="立案时间">
          </el-table-column>
          <el-table-column
            prop="undertakerCard"
            header-align="center"
            align="center"
            label="案件承办人执法证编号">
          </el-table-column>
          <el-table-column
            prop="undertakerName"
            header-align="center"
            align="center"
            label="案件承办人姓名">
          </el-table-column>
          <el-table-column
            prop="unitIdea"
            header-align="center"
            align="center"
            label="承办单位意见">
          </el-table-column>
          <el-table-column
            prop="unitName"
            header-align="center"
            align="center"
            label="单位名称">
          </el-table-column>
          <el-table-column
            fixed="right"
            header-align="center"
            align="center"
            label="操作">
            <template slot-scope="scope">
              <el-button v-if="permissions.process_finalreport_edit" type="text" size="small" icon="el-icon-edit"
                         @click="addOrUpdateHandle(scope.row.id)">修改
              </el-button>
              <el-button v-if="permissions.process_finalreport_del" type="text" size="small" icon="el-icon-delete"
                         @click="deleteHandle(scope.row.id)">删除
              </el-button>
              <el-button v-if="permissions.process_photosevidence_wordpdf" type="text" size="small"
                         icon="el-icon-download" @click="download(scope.row.id)">下载
              </el-button>
              <el-button v-if="permissions.process_photosevidence_wordpdf" type="text" size="small" icon="el-icon-view"
                         @click="viewPdf(scope.row.id)">预览
              </el-button>
            </template>
          </el-table-column>
        </el-table>
      </div>

      <div class="avue-crud__pagination">
        <el-pagination
          @size-change="sizeChangeHandle"
          @current-change="currentChangeHandle"
          :current-page="pageIndex"
          :page-sizes="[10, 20, 50, 100]"
          :page-size="pageSize"
          :total="totalPage"
          background
          layout="total, sizes, prev, pager, next, jumper">
        </el-pagination>
      </div>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form v-if="addOrUpdateVisible" ref="addOrUpdate" @refreshDataList="getDataList"></table-form>
    </basic-container>
  </div>
</template>

<script>
  import {fetchList, delObj,createWord} from '@/api/finalreport'
  import {wordToPdf, download, viewPdf} from '@/api/process/wordcommon'
  import TableForm from './finalreport-form'
  import {mapGetters} from 'vuex'

  export default {
    data() {
      return {
        dataForm: {
          key: ''
        },
        dataList: [],
        pageIndex: 1,
        pageSize: 10,
        totalPage: 0,
        dataListLoading: false,
        addOrUpdateVisible: false
      }
    },
    components: {
      TableForm
    },
    created() {
      this.getDataList()
    },
    computed: {
      ...mapGetters(['permissions'])
    },
    methods: {
      // 获取数据列表
      getDataList() {
        this.dataListLoading = true
        fetchList(Object.assign({
          current: this.pageIndex,
          size: this.pageSize
        })).then(response => {
          this.dataList = response.data.data.records
          this.totalPage = response.data.data.total
        })
        this.dataListLoading = false
      },
      // 每页数
      sizeChangeHandle(val) {
        this.pageSize = val
        this.pageIndex = 1
        this.getDataList()
      },
      // 当前页
      currentChangeHandle(val) {
        this.pageIndex = val
        this.getDataList()
      },
      // 新增 / 修改
      addOrUpdateHandle(id) {
        this.addOrUpdateVisible = true
        this.$nextTick(() => {
          this.$refs.addOrUpdate.init(id)
        })
      },
      // 删除
      deleteHandle(id) {
        this.$confirm('是否确认删除ID为' + id, '提示', {
          confirmButtonText: '确定',
          cancelButtonText: '取消',
          type: 'warning'
        }).then(function () {
          return delObj(id)
        }).then(data => {
          this.$message.success('删除成功')
          this.getDataList()
        })
      },
      //下载word
      download(id) {
        createWord(id).then(res => {
          if (res.data.code == 0) {
            download(res.data.data)
          }
        })
      },

      //预览pdf
      viewPdf(id) {
        createWord(id).then(res => {
          if (res.data.code == 0) {
            wordToPdf(res.data.data).then(res1 => {
              viewPdf(res1.data.data)
            })
          }
        })
      },
    }
  }
</script>
